@@ -1,7 +1,5 @@
-#![allow(dead_code)]
-
 /**
-Simple Dates. Do not expect anything fancy from this part of the library.
+Simple Dates. Do not expect anything fancy from this part of the library, as the focus does not lie on date-functions.
 */
 pub struct Date {
     year:      i32,
@@ -251,7 +249,47 @@ impl std::fmt::Display for Date {
              &format!("{:0>2}", &self.day.to_string())    + " " +
              &format!("{:0>2}", &self.hour.to_string())   + ":" +
              &format!("{:0>2}", &self.minute.to_string()) + ":" +
-             &format!("{:0>2}", &self.second.to_string()) + ":" ;
+             &format!("{:0>2}", &self.second.to_string());
         write!(f, "{}", finstring)
     }
+}
+
+impl PartialEq for Date {
+    fn eq(&self, other: &Self) -> bool {
+        self.year == other.year && self.month == other.month && self.day == other.day && self.hour == other.hour && self.minute == other.minute && self.second == other.second
+    }
+
+    fn ne(&self, other: &Self) -> bool {
+        !(self == other)
+    }
+}
+
+impl core::cmp::PartialOrd for Date {
+    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        match self.year.partial_cmp(&other.year) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        match self.month.partial_cmp(&other.month) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        match self.day.partial_cmp(&other.day) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        match self.hour.partial_cmp(&other.hour) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        match self.minute.partial_cmp(&other.minute) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        match self.second.partial_cmp(&other.second) {
+            Some(core::cmp::Ordering::Equal) => {}
+            ord => return ord,
+        }
+        None
+    }
 }
\ No newline at end of file
